Comfort models
==============

.. testsetup::

    from pythermalcomfort import *
    from pythermalcomfort.models import *


PMV
---

.. autofunction:: pythermalcomfort.models.pmv

PMV PPD
-------

.. autofunction:: pythermalcomfort.models.pmv_ppd

SET
---

.. autofunction:: pythermalcomfort.models.set_tmp

References
----------
.. [1]  ANSI, & ASHRAE. (2017). Thermal Environmental Conditions for Human Occupancy. Atlanta.


Adaptive ASHRAE
---------------

.. autofunction:: pythermalcomfort.models.adaptive_ashrae


Psychrometrics functions
========================

.. automodule:: pythermalcomfort.psychrometrics
    :members:
